Introduction
============


.. image:: https://readthedocs.org/projects/circuitpython-scales/badge/?version=latest
    :target: https://circuitpython-scales.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


.. image:: https://github.com/jposada202020/CircuitPython_scales/workflows/Build%20CI/badge.svg
    :target: https://github.com/jposada202020/CircuitPython_scales/actions
    :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

Allows display data in a graduated level


Dependencies
=============
This driver depends on:

* `Adafruit CircuitPython <https://github.com/adafruit/circuitpython>`_

Please ensure all dependencies are available on the CircuitPython filesystem.
This is easily achieved by downloading
`the Adafruit library and driver bundle <https://circuitpython.org/libraries>`_
or individual libraries can be installed using
`circup <https://github.com/adafruit/circup>`_.

Usage Example
=============

.. image:: https://raw.githubusercontent.com/jposada202020/CircuitPython_scales/main/docs/scales.png

Please se the ``scales_simpletest.py`` example for initial reference


Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/jposada202020/CircuitPython_scales/blob/main/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.

Documentation
=============

For information on building library documentation, please check out
`this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.
